from charmhelpers.core import hookenv, host
from charms.reactive import (
    when, when_not, set_state, remove_state
)
from charms.layer import snap
import subprocess


SNAP_NAME = 'prometheus-nrpe-exporter'
SVC_NAME = 'snap.prometheus-nrpe-exporter.daemon'
PORT_NUMBER = '9275'


@when_not('nrpe-exporter.installed')
def install_packages():
    hookenv.status_set('maintenance', 'Installing software')
    config = hookenv.config()
    channel = config.get('snap_channel', 'stable')
    # prometheus-nrpe-exporter snap needs to read /etc. So classic
    # confinement is needed. It needs to be granted by snapstore devs
    # but for now we can attach the snap as resource
    snap.install(SNAP_NAME, channel=channel, force_dangerous=False, classic=True)
    hookenv.status_set('active', 'Exporter installed')
    hookenv.open_port(PORT_NUMBER)
    set_state('nrpe-exporter.installed')


@when('nrpe-exporter.installed')
def check_status():
    config = hookenv.config()
    if config.changed('snap_channel'):
        remove_state('nrpe-exporter.installed')
        return
    if not host.service_running(SVC_NAME):
        hookenv.status_set('maintenance', 'Service is down, starting')
        hookenv.log('Service {} is down, starting...'.format(SVC_NAME))
        host.service_start(SVC_NAME)
        hookenv.status_set('active', 'Service started')
    else:
        hookenv.status_set('active', 'Service is up')
        set_state('nrpe-exporter.started')


# Relations
@when('nrpe-exporter.started')
@when('scrape.available')
def configure_scrape_relation(scrape_service):
    scrape_service.configure(PORT_NUMBER)
